==> v8.3.zip: ru_twords_ru_tw/bible/other/commit.md <==
# посвящать, определять, избирать

## Определение:

Посвящать — значит полностью отдать себя кому-либо или чему-либо.

* “Посвященным” можно назвать человека, который принял какое-либо решение и твёрдо намерен его выполнить.
* “Посвящать” кого-то на исполнение определенного задания — значит поручать этому человеку что-либо. Например, во 2 Послании Коринфянам Павел говорит, что Бог “освятил” нас на служение примирения, и мы должны примирить неверующих с Богом.
* В английском языке слово “commit”, переводимое как “посвящать”, может употребляться в значении “совершать” и нередко имеет значение “поступить неправильно”. Например, “совершить грех” (“commit a sin”), “совершить прелюбодеяние” (“commit adultery”), “совершить убийство” (“commit murder”).
* Выражение “посвятил его на дело” можно ещё перевести как “дал ему задание”, “доверил ему определённую работу”, “возложил на него ответственность за что-либо”.
* Слово “посвящение” можно перевести как “возложенная ответственность”, “данное обещание”.

(См. также: [прелюбодеяние](../kt/adultery.md), [верный](../kt/faithful.md), [обещание](../kt/promise.md), [грех](../kt/sin.md))

## Ссылки на библейский текст:

* [1 Пар. 28:6-7](rc://*/tn/help/1ch/28/06)
* [1 Пет. 2:21-23](rc://*/tn/help/1pe/02/21)
* [Иер. 2:12-13](rc://*/tn/help/jer/02/12)
* [Мф. 13:40-43](rc://*/tn/help/mat/13/40)
* [Пс. 58:1-2](rc://*/tn/help/psa/058/001)

## Данные о слове:

* Номера Стронга: H539, H817, H1361, H1497, H1500, H1540, H1556, H2181, H2388, H2398, H2399, H2403, H4560, H4603, H5003, H5753, H5766, H5771, H6213, H6466, H7683, H7760, H7847, G264, G2038, G2716, G3429, G3431, G3860, G3872, G3908, G4102, G4160, G4203

==> v9.2.zip: ru_twords_ru_tw/bible/other/commit.md <==
# посвящать, определять, избирать

## Определение:

Посвящать — значит полностью отдать себя кому-либо или чему-либо. 

* “Посвященным” можно назвать человека, который принял какое-либо решение и твёрдо намерен его выполнить.
* “Посвящать” кого-то на исполнение определенного задания — значит поручать этому человеку что-либо. Например, во 2 Послании Коринфянам Павел говорит, что Бог “освятил” нас на служение примирения, и мы должны примирить неверующих с Богом.
* В английском языке слово “commit”, переводимое как “посвящать”, может употребляться в значении “совершать” и нередко имеет значение “поступить неправильно”. Например, “совершить грех” (“commit a sin”), “совершить прелюбодеяние” (“commit adultery”), “совершить убийство” (“commit murder”).
* Выражение “посвятил его на дело” можно ещё перевести как “дал ему задание”, “доверил ему определённую работу”, “возложил на него ответственность за что-либо”.
* Слово “посвящение” можно перевести как “возложенная ответственность”, “данное обещание”.

(См. также: [прелюбодеяние](../kt/adultery.md), [верный](../kt/faithful.md), [обещание](../kt/promise.md), [грех](../kt/sin.md))

## Ссылки на библейский текст:

* [1 Пар. 28:6-7](rc://ru/tn/help/1ch/28/06)
* [1 Пет. 2:21-23](rc://ru/tn/help/1pe/02/21)
* [Иер. 2:12-13](rc://ru/tn/help/jer/02/12)
* [Мф. 13:40-43](rc://ru/tn/help/mat/13/40)
* [Пс. 58:1-2](rc://ru/tn/help/psa/058/001)

## Данные о слове:

* Номера Стронга: H539, H817, H1361, H1497, H1500, H1540, H1556, H2181, H2388, H2398, H2399, H2403, H4560, H4603, H5003, H5753, H5766, H5771, H6213, H6466, H7683, H7760, H7847, G264, G2038, G2716, G3429, G3431, G3860, G3872, G3908, G4102, G4160, G4203
